@@ -7,7 +7,7 @@
 #include <sys/xattr.h>
 #include "policy.h"
 
-int getfilecon_raw(const char *path, security_context_t * context)
+int getfilecon_raw(const char *path, char ** context)
 {
 	char *buf;
 	ssize_t size;
@@ -49,12 +49,11 @@ int getfilecon_raw(const char *path, security_context_t * context)
 	return ret;
 }
 
-hidden_def(getfilecon_raw)
 
-int getfilecon(const char *path, security_context_t * context)
+int getfilecon(const char *path, char ** context)
 {
 	int ret;
-	security_context_t rcontext;
+	char * rcontext = NULL;
 
 	*context = NULL;
 
@@ -70,4 +69,3 @@ int getfilecon(const char *path, security_context_t * context)
 	return ret;
 }
 
-hidden_def(getfilecon)
